pub enum IdentityServiceResponseKind {
Ready,
AuthSuccess(AuthResponseSuccess),
AuthFailure(String),
}Expand description
Enum representing the kind of response from the Identity Service.
Variants
Ready
Represents a ready state.
AuthSuccess(AuthResponseSuccess)
Represents a successful authentication response.
AuthFailure(String)
Represents a failed authentication response with an error message.