IdentityServiceResponseMessage

Struct IdentityServiceResponseMessage 

pub struct IdentityServiceResponseMessage { /* private fields */ }
Represents a response message from the Identity Service.

This struct is used to store the details of a response message from the Identity Service. It includes the kind of the response, the delegations, the user’s public key, the authentication method used, and the error message in case of failure.

Implementations

Source

impl IdentityServiceResponseMessage

pub fn kind(&self) -> Result<IdentityServiceResponseKind, String>

Returns the kind of the Identity Service response.