InternetIdentityAuthRequest

Struct InternetIdentityAuthRequest 

pub struct InternetIdentityAuthRequest {
    pub kind: String,
    pub session_public_key: Vec<u8>,
    pub max_time_to_live: Option<u64>,
    pub allow_pin_authentication: Option<bool>,
    pub derivation_origin: Option<String>,
}
Represents an Internet Identity authentication request.

This struct is used to send an authentication request to the Internet Identity Service. It includes all the necessary parameters that the Internet Identity Service needs to authenticate a user.

Fields

kind: String

The kind of request. This is typically set to “authorize-client”.

session_public_key: Vec<u8>

The public key of the session.

max_time_to_live: Option<u64>

The maximum time to live for the session, in nanoseconds. If not provided, a default value is used.

allow_pin_authentication: Option<bool>

If present, indicates whether or not the Identity Provider should allow the user to authenticate and/or register using a temporary key/PIN identity.

derivation_origin: Option<String>

Origin for Identity Provider to use while generating the delegated identity. For II, the derivation origin must authorize this origin by setting a record at <derivation-origin>/.well-known/ii-alternative-origins.