pub struct IdleManagerOptions {
pub on_idle: Arc<Mutex<Vec<Box<dyn FnMut() + Send>>>>,
pub idle_timeout: Option<u32>,
pub capture_scroll: Option<bool>,
pub scroll_debounce: Option<u32>,
}Expand description
IdleManagerOptions is a struct that contains options for configuring an IdleManager.
Fields
on_idle: Arc<Mutex<Vec<Box<dyn FnMut() + Send>>>>A callback function to be executed when the system becomes idle.
idle_timeout: Option<u32>The duration of inactivity after which the system is considered idle.
capture_scroll: Option<bool>A flag indicating whether to capture scroll events.
scroll_debounce: Option<u32>A delay for debouncing scroll events.
Implementations
Sourceimpl IdleManagerOptions
impl IdleManagerOptions
Sourcepub fn builder() -> IdleManagerOptionsBuilder
pub fn builder() -> IdleManagerOptionsBuilder
Returns a new IdleManagerOptionsBuilder to construct an IdleManagerOptions struct.