pub struct IdleManagerOptionsBuilder { /* private fields */ }Expand description
Builder for the IdleManagerOptions.
Implementations
sourceimpl IdleManagerOptionsBuilder
impl IdleManagerOptionsBuilder
sourcepub fn on_idle(&mut self, on_idle: fn()) -> &mut Self
pub fn on_idle(&mut self, on_idle: fn()) -> &mut Self
A callback function to be executed when the system becomes idle.
sourcepub fn idle_timeout(&mut self, idle_timeout: u32) -> &mut Self
pub fn idle_timeout(&mut self, idle_timeout: u32) -> &mut Self
The duration of inactivity after which the system is considered idle.
sourcepub fn capture_scroll(&mut self, capture_scroll: bool) -> &mut Self
pub fn capture_scroll(&mut self, capture_scroll: bool) -> &mut Self
A flag indicating whether to capture scroll events.
sourcepub fn scroll_debounce(&mut self, scroll_debounce: u32) -> &mut Self
pub fn scroll_debounce(&mut self, scroll_debounce: u32) -> &mut Self
A delay for debouncing scroll events.
sourcepub fn build(&mut self) -> IdleManagerOptions
pub fn build(&mut self) -> IdleManagerOptions
Builds the IdleManagerOptions struct.