NativeAuthClientCreateOptionsBuilder

Struct NativeAuthClientCreateOptionsBuilder 

pub struct NativeAuthClientCreateOptionsBuilder<S: State = Empty> { /* private fields */ }
Available on crate feature native only.
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> NativeAuthClientCreateOptionsBuilder<S>

pub fn build(self) -> NativeAuthClientCreateOptions
where S: IsComplete,

Finish building and return the requested object

pub fn identity( self, value: ArcIdentity, ) -> NativeAuthClientCreateOptionsBuilder<SetIdentity<S>>
where S::Identity: IsUnset,

Optional (Some / Option setters). An optional identity to use as the base. If not provided, an Ed25519 key pair will be used.

pub fn maybe_identity( self, value: Option<ArcIdentity>, ) -> NativeAuthClientCreateOptionsBuilder<SetIdentity<S>>
where S::Identity: IsUnset,

Optional (Some / Option setters). An optional identity to use as the base. If not provided, an Ed25519 key pair will be used.

pub fn storage( self, value: impl Into<Box<dyn AuthClientStorage>>, ) -> NativeAuthClientCreateOptionsBuilder<SetStorage<S>>
where S::Storage: IsUnset,

Required.

Storage with get, set, and remove methods.

pub fn key_type( self, value: BaseKeyType, ) -> NativeAuthClientCreateOptionsBuilder<SetKeyType<S>>
where S::KeyType: IsUnset,

Optional (Some / Option setters). The type of key to use for the base key. If not provided, Ed25519 will be used by default.

pub fn maybe_key_type( self, value: Option<BaseKeyType>, ) -> NativeAuthClientCreateOptionsBuilder<SetKeyType<S>>
where S::KeyType: IsUnset,

Optional (Some / Option setters). The type of key to use for the base key. If not provided, Ed25519 will be used by default.

pub fn idle_options( self, value: IdleOptions, ) -> NativeAuthClientCreateOptionsBuilder<SetIdleOptions<S>>
where S::IdleOptions: IsUnset,

Optional (Some / Option setters). Options for handling idle timeouts. If not provided, default options will be used.

pub fn maybe_idle_options( self, value: Option<IdleOptions>, ) -> NativeAuthClientCreateOptionsBuilder<SetIdleOptions<S>>
where S::IdleOptions: IsUnset,

Optional (Some / Option setters). Options for handling idle timeouts. If not provided, default options will be used.