pub struct AuthClientLoginOptionsBuilder { /* private fields */ }Expand description
Builder for the AuthClientLoginOptions.
Implementations
Sourceimpl AuthClientLoginOptionsBuilder
impl AuthClientLoginOptionsBuilder
Sourcepub fn identity_provider(self, identity_provider: Url) -> Self
pub fn identity_provider(self, identity_provider: Url) -> Self
The URL of the identity provider.
Sourcepub fn max_time_to_live(self, max_time_to_live: u64) -> Self
pub fn max_time_to_live(self, max_time_to_live: u64) -> Self
Expiration of the authentication in nanoseconds.
Sourcepub fn allow_pin_authentication(self, allow_pin_authentication: bool) -> Self
pub fn allow_pin_authentication(self, allow_pin_authentication: bool) -> Self
If present, indicates whether or not the Identity Provider should allow the user to authenticate and/or register using a temporary key/PIN identity.
Authenticating dapps may want to prevent users from using Temporary keys/PIN identities because Temporary keys/PIN identities are less secure than Passkeys (webauthn credentials) and because Temporary keys/PIN identities generally only live in a browser database (which may get cleared by the browser/OS).
Sourcepub fn derivation_origin(self, derivation_origin: Url) -> Self
pub fn derivation_origin(self, derivation_origin: Url) -> Self
Origin for Identity Provider to use while generating the delegated identity. For II, the derivation origin must authorize this origin by setting a record at <derivation-origin>/.well-known/ii-alternative-origins.
See: https://github.com/dfinity/internet-identity/blob/main/docs/ii-spec.mdx#alternative-frontend-origins
Sourcepub fn window_opener_features(self, window_opener_features: String) -> Self
pub fn window_opener_features(self, window_opener_features: String) -> Self
Sourcepub fn on_success<F>(self, on_success: F) -> Self
pub fn on_success<F>(self, on_success: F) -> Self
Callback once login has completed.
Sourcepub fn custom_values(self, custom_values: HashMap<String, Value>) -> Self
pub fn custom_values(self, custom_values: HashMap<String, Value>) -> Self
Extra values to be passed in the login request during the authorize-ready phase.
Sourcepub fn build(self) -> AuthClientLoginOptions
pub fn build(self) -> AuthClientLoginOptions
Build the AuthClientLoginOptions.