Simple interface to get your web application authenticated with the Internet Identity Service for Rust.
This crate is intended for use in front-end WebAssembly environments in conjunction with ic-agent.
Modules
Structs
- The tool for managing authentication and identity. It maintains the state of the user’s identity and provides methods for authentication.
- Builder for the
AuthClient. - Options for creating a new
AuthClient. - Options for the
AuthClient::login_with_options. - Builder for the
AuthClientLoginOptions. - Represents a successful authentication response.
- Options for handling idle timeouts.
- Builder for
IdleOptions.
Enums
- Enum representing the type of base key used for the identity.
- Enum representing the different types of identity to use as the base.
Constants
- The error message when a user interrupts the authentication process.