Crate ic_auth_client

source ·
Simple interface to get your web application authenticated with the Internet Identity Service for Rust.

This crate is intended for use in front-end WebAssembly environments in conjunction with ic-agent.

Modules

Structs

Enums

  • Enum representing the type of base key used for the identity.
  • Enum representing the different types of identity to use as the base.

Constants