pub struct IdentityServiceResponseMessage { /* private fields */ }Expand description
Represents a response message from the Identity Service.
This struct is used to store the details of a response message from the Identity Service. It includes the kind of the response, the delegations, the user’s public key, the authentication method used, and the error message in case of failure.
Implementations
Sourceimpl IdentityServiceResponseMessage
impl IdentityServiceResponseMessage
Sourcepub fn kind(&self) -> Result<IdentityServiceResponseKind, String>
pub fn kind(&self) -> Result<IdentityServiceResponseKind, String>
Returns the kind of the Identity Service response.