Struct ic_auth_client::IdleOptionsBuilder

source ·
pub struct IdleOptionsBuilder { /* private fields */ }
Builder for IdleOptions.

Implementations

source

impl IdleOptionsBuilder

source

pub fn disable_idle(&mut self, disable_idle: bool) -> &mut Self

If set to true, disables the idle timeout functionality.

source

pub fn disable_default_idle_callback( &mut self, disable_default_idle_callback: bool, ) -> &mut Self

If set to true, disables the default idle timeout callback.

source

pub fn idle_manager_options( &mut self, idle_manager_options: IdleManagerOptions, ) -> &mut Self

Options for the IdleManager that handles idle timeouts.

source

pub fn on_idle(&mut self, on_idle: fn()) -> &mut Self

A callback function to be executed when the system becomes idle.

source

pub fn idle_timeout(&mut self, idle_timeout: u32) -> &mut Self

The duration of inactivity after which the system is considered idle.

source

pub fn scroll_debounce(&mut self, scroll_debounce: u32) -> &mut Self

A delay for debouncing scroll events.

source

pub fn capture_scroll(&mut self, capture_scroll: bool) -> &mut Self

A flag indicating whether to capture scroll events.

source

pub fn build(&mut self) -> IdleOptions

Build the IdleOptions.