Struct ic_auth_client::IdleOptionsBuilder
source · pub struct IdleOptionsBuilder { /* private fields */ }Expand description
Builder for IdleOptions.
Implementations
sourceimpl IdleOptionsBuilder
impl IdleOptionsBuilder
sourcepub fn disable_idle(&mut self, disable_idle: bool) -> &mut Self
pub fn disable_idle(&mut self, disable_idle: bool) -> &mut Self
If set to true, disables the idle timeout functionality.
sourcepub fn disable_default_idle_callback(
&mut self,
disable_default_idle_callback: bool,
) -> &mut Self
pub fn disable_default_idle_callback( &mut self, disable_default_idle_callback: bool, ) -> &mut Self
If set to true, disables the default idle timeout callback.
sourcepub fn idle_manager_options(
&mut self,
idle_manager_options: IdleManagerOptions,
) -> &mut Self
pub fn idle_manager_options( &mut self, idle_manager_options: IdleManagerOptions, ) -> &mut Self
Options for the IdleManager that handles idle timeouts.
sourcepub fn on_idle(&mut self, on_idle: fn()) -> &mut Self
pub fn on_idle(&mut self, on_idle: fn()) -> &mut Self
A callback function to be executed when the system becomes idle.
sourcepub fn idle_timeout(&mut self, idle_timeout: u32) -> &mut Self
pub fn idle_timeout(&mut self, idle_timeout: u32) -> &mut Self
The duration of inactivity after which the system is considered idle.
sourcepub fn scroll_debounce(&mut self, scroll_debounce: u32) -> &mut Self
pub fn scroll_debounce(&mut self, scroll_debounce: u32) -> &mut Self
A delay for debouncing scroll events.
sourcepub fn capture_scroll(&mut self, capture_scroll: bool) -> &mut Self
pub fn capture_scroll(&mut self, capture_scroll: bool) -> &mut Self
A flag indicating whether to capture scroll events.
sourcepub fn build(&mut self) -> IdleOptions
pub fn build(&mut self) -> IdleOptions
Build the IdleOptions.